from django.core.exceptions import ImproperlyConfigured
from cent.core import generate_channel_sign
from instant.conf import PUBLIC_CHANNEL, SECRET_KEY


def signed_response(channel, client):
    signature = generate_channel_sign(SECRET_KEY, client, channel, info="")
    return {"sign": signature}


def _get_public_channel():
    return PUBLIC_CHANNEL


def _ensure_channel_is_private(chanconf):
    chan = chanconf[0]
    if chan.startswith("$") is False:
        msg = "Channel " + chan + " must start with a $ to be considered private"
        raise ImproperlyConfigured(msg)



from django.core.exceptions import ImproperlyConfigured
from django.conf import settings


try:
    SECRET_KEY = getattr(settings, 'CENTRIFUGO_SECRET_KEY')
except ImportError:
    raise ImproperlyConfigured(
        u"The Centrifugo secret key must be set in settings.py with CENTRIFUGO_SECRET_KEY")
CENTRIFUGO_HOST = getattr(settings, 'CENTRIFUGO_HOST', 'http://localhost')
CENTRIFUGO_PORT = getattr(settings, 'CENTRIFUGO_PORT', 8001)

SITE_SLUG = getattr(settings, 'SITE_SLUG', 'site')
SITE_NAME = getattr(settings, 'SITE_NAME', 'Site')

BROADCAST_WITH = getattr(settings, 'INSTANT_BROADCAST_WITH', "py")

ENABLE_USERS_CHANNEL = getattr(settings, 'INSTANT_ENABLE_USERS_CHANNEL', False)
ENABLE_STAFF_CHANNEL = getattr(settings, 'INSTANT_ENABLE_STAFF_CHANNEL', False)
ENABLE_SUPERUSER_CHANNEL = getattr(
    settings, 'INSTANT_ENABLE_SUPERUSER_CHANNEL', False)

DEFAULT_USERS_CHANNEL = "$" + SITE_SLUG + "_users"
DEFAULT_STAFF_CHANNEL = "$" + SITE_SLUG + "_staff"
DEFAULT_SUPERUSER_CHANNEL = "$" + SITE_SLUG + "_admin"
public_channel = SITE_SLUG + '_public'
PUBLIC_CHANNEL = getattr(settings, 'INSTANT_PUBLIC_CHANNEL', public_channel)

PUBLIC_CHANNELS = getattr(settings, 'INSTANT_PUBLIC_CHANNELS', ())
USERS_CHANNELS = getattr(
    settings, 'INSTANT_USERS_CHANNELS', ())
STAFF_CHANNELS = getattr(settings, 'INSTANT_STAFF_CHANNELS', ())
SUPERUSER_CHANNELS = getattr(settings, 'INSTANT_SUPERUSER_CHANNELS', ())
USERS_CHANNELS = getattr(settings, 'INSTANT_USERS_CHANNELS', ())


EXCLUDE = getattr(settings, 'INSTANT_EXCLUDE', ["__presence__"])



from __future__ import unicode_literals
import os
from django.apps import AppConfig
from django.utils._os import safe_join
from django.core.exceptions import ImproperlyConfigured


HANDLERS = []


class InstantConfig(AppConfig):
    name = 'instant'

    def ready(self):
        global HANDLERS
        from django.conf import settings
        from instant.utils import _ensure_channel_is_private
        from instant.conf import PUBLIC_CHANNELS, USERS_CHANNELS, STAFF_CHANNELS, SUPERUSER_CHANNELS
        # ensure that the private channels are really private
        private_chans = USERS_CHANNELS + STAFF_CHANNELS + SUPERUSER_CHANNELS
        for chan in private_chans:
            _ensure_channel_is_private(chan)
        all_chans = private_chans + PUBLIC_CHANNELS
        # check if the default handler exists
        if len(all_chans) > 0:
            d = "templates/instant/handlers"
            msg = "Please create a /templates/instant/handlers/default.js file for your custom channels"
            try:
                handlers_dir = safe_join(settings.BASE_DIR, d)
            except:
                raise ImproperlyConfigured(msg)
            if os.path.isdir(handlers_dir) is False:
                raise ImproperlyConfigured(msg)
            if os.path.exists(handlers_dir + "/default.js") is False:
                raise ImproperlyConfigured(msg)
            # map default handlers
            handlers = os.listdir(handlers_dir)
            for handler in handlers:
                HANDLERS.append(handler.replace(".js", ""))
